USE [igops]
GO

DROP VIEW IF EXISTS idsrc_publication_overview_v
DROP VIEW IF EXISTS bulk_data_v
GO

CREATE VIEW bulk_data_v AS
    SELECT
        ds.name AS source_name,
        dp.id,
        dp.data_producer_type,
        dp.end_time,
        dp.message,
        dp.start_time,
        dp.status,
        afeed.id AS advisor_feed,
        afeed.source_type,
        afeed.entity_type,
        afeed.name,
        afeed.description,
        afeed.configuration,
        afeed.is_active,
        afeed.is_deleted
    FROM data_production dp
        JOIN advisor_feed_curation afc ON  afc.id = dp.id
        JOIN advisor_feed afeed ON  afc.advisor_feed = afeed.id
        LEFT JOIN data_source ds ON  ds.id = afeed.application
    UNION ALL
    SELECT
        ds.name AS source_name,
        dp.id,
        dp.data_producer_type,
        dp.end_time,
        dp.message,
        dp.start_time,
        dp.status,
        afeed.id AS advisor_feed,
        afeed.source_type,
        afeed.entity_type,
        afeed.name,
        afeed.description,
        afeed.configuration,
        afeed.is_active,
        afeed.is_deleted
    FROM data_production dp
        JOIN advisor_feed_generation afg ON  afg.id = dp.id
        JOIN advisor_feed afeed ON  afg.advisor_feed = afeed.id
        LEFT JOIN data_source ds ON  ds.id = afeed.application
GO

CREATE VIEW idsrc_publication_overview_v AS
  SELECT 
    snap.[timestamp] AS publication_time,
    (SELECT count(su.id) AS count FROM suser su WHERE su.effective = 1) AS unique_ident_count
  FROM snapshot_state snapstate
    JOIN snapshot snap ON snap.precursor = snapstate.current_unification_snapshot
GO

GRANT SELECT ON bulk_data_v TO ig_report_role
GRANT SELECT ON idsrc_publication_overview_v TO ig_report_role